/**
 * Represents an instance of a row in a table of a database.
 * Wraps the raw Row data and provides methods for interacting with it.
 */
export class WrappedRow<RowShape> {
	protected row: RowShape;

	constructor(row: RowShape) {
		this.row = row;
	}

	/**
	 * @returns The row data as a JSON string.
	 */
	toJSON(): string {
		return JSON.stringify(this.row);
	}

	/**
	 * Exports the raw row data.
	 * @returns The raw row data.
	 */
	unwrap(): RowShape {
		return this.row;
	}
}
